==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-stream-properties-dialog.h <==
/*
 * $Id: st-stream-properties-dialog.h,v 1.9 2004/01/05 19:44:10 jylefort Exp $
 *
 * Copyright (c) 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STREAM_PROPERTIES_DIALOG_H
#define _ST_STREAM_PROPERTIES_DIALOG_H

#include <gtk/gtk.h>
#include "sgtk-dialog.h"
#include "st-handler.h"

#define ST_TYPE_STREAM_PROPERTIES_DIALOG		(st_stream_properties_dialog_get_type())
#define ST_STREAM_PROPERTIES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialog))
#define ST_STREAM_PROPERTIES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialogClass))
#define ST_IS_STREAM_PROPERTIES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG))
#define ST_IS_STREAM_PROPERTIES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_STREAM_PROPERTIES_DIALOG))
#define ST_STREAM_PROPERTIES_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialogClass))

typedef struct
{
  sGtkDialog		dialog;

  STHandler		*handler;
  STStream		*stream;

  GtkWidget		*table;
  GSList		*entries;
} STStreamPropertiesDialog;

typedef struct
{
  sGtkDialogClass	parent_class;
} STStreamPropertiesDialogClass;

GType		st_stream_properties_dialog_get_type	(void);
GtkWidget	*st_stream_properties_dialog_new	(GtkWindow *parent);

void st_stream_properties_dialog_set_handler (STStreamPropertiesDialog *dialog,
					      STHandler		       *handler);
void st_stream_properties_dialog_set_stream  (STStreamPropertiesDialog *dialog,
					      STStream		       *stream);

#endif /* _ST_STREAM_PROPERTIES_DIALOG_H */

==> streamtuner-0.12.4.tar.gz: streamtuner-0.12.4/src/streamtuner/st-stream-properties-dialog.h <==
/*
 * $Id: st-stream-properties-dialog.h,v 1.20 2004/03/15 19:06:41 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STREAM_PROPERTIES_DIALOG_H
#define _ST_STREAM_PROPERTIES_DIALOG_H

#include <gtk/gtk.h>
#include "sgtk-dialog.h"
#include "st-handler.h"
#include "st-stream-bag.h"
#include "st-shell.h"

#define ST_TYPE_STREAM_PROPERTIES_DIALOG		(st_stream_properties_dialog_get_type())
#define ST_STREAM_PROPERTIES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialog))
#define ST_STREAM_PROPERTIES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialogClass))
#define ST_IS_STREAM_PROPERTIES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG))
#define ST_IS_STREAM_PROPERTIES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_STREAM_PROPERTIES_DIALOG))
#define ST_STREAM_PROPERTIES_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_STREAM_PROPERTIES_DIALOG, STStreamPropertiesDialogClass))

typedef struct _STStreamPropertiesDialogPrivate STStreamPropertiesDialogPrivate;

typedef struct
{
  sGtkDialog				dialog;

  STStreamPropertiesDialogPrivate	*priv;
} STStreamPropertiesDialog;

typedef struct
{
  sGtkDialogClass	parent_class;
} STStreamPropertiesDialogClass;

GType		st_stream_properties_dialog_get_type	(void);
GtkWidget	*st_stream_properties_dialog_new	(STShell *shell);

void st_stream_properties_dialog_set_stream  (STStreamPropertiesDialog *dialog,
					      STStreamBag	       *stream_bag);
void st_stream_properties_dialog_update_sensitivity (STStreamPropertiesDialog *dialog);

void st_stream_properties_dialog_apply	(STStreamPropertiesDialog *dialog);
void st_stream_properties_dialog_cancel	(STStreamPropertiesDialog *dialog);

#endif /* _ST_STREAM_PROPERTIES_DIALOG_H */
